
# q-expansion of newform 507.8.a.d, downloaded from the LMFDB on 28 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 507
weight = 8
poly_data = [9008, -452, -453, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, 1, 0, 0], 1], [[-1526, -1251, -4, 3], 83], [[-5744, 334, 29, -1], 83]]

hecke_ring_character_values = None
aps_data = [[2, -1, 0, 0], [-27, 0, 0, 0], [66, 6, 1, -4], [314, -70, 7, 0], [-1202, -80, 100, -28], [0, 0, 0, 0], [5590, 292, 462, 0], [7006, -698, 545, 192], [7660, -3464, -368, -424], [59242, -4688, -1772, 584], [-133002, 314, 1735, -2328], [148606, 17804, 898, -1896], [-49534, -6946, 2313, 4068], [-475912, 9916, 2594, 5352], [50478, 8532, 8462, -1004], [1128902, -23272, 4952, 5344], [-1703050, -28636, -3222, 7644], [175218, -121208, -45304, 8736], [576262, -43174, 23911, 27768], [-620998, 5432, 9692, 50548], [-2568850, -91108, -6182, -21576], [1264592, 36248, 103132, -8592], [-4134158, 21556, 58778, -58460], [898602, -192462, 75431, -19220], [-4294098, -222188, -111514, 74952], [7102, 216580, 37578, 136296], [-1933116, -454532, -126550, 33768], [-5938008, -392832, -85468, 100360], [1459718, 182936, -216380, 35952], [9078558, 189936, 204296, 156664], [-12016636, -663172, -291014, -65184], [-3379864, -761128, -94672, -394184], [-8315966, -965570, -20023, 330532], [881484, -1348912, 470776, -165528], [-845286, -738198, 258575, -636428], [13708290, -1848210, 36357, -408840], [9971726, -2617440, -24852, -648624], [24907954, -685558, 595207, -190176], [16947302, -1040380, -411914, -232108], [6734526, 2063388, 251278, 861464], [-5039196, -2714688, 25892, 524800], [-52957930, 410880, 1066404, -440256], [18142472, 1585088, -1179180, -45216], [73926638, 182888, 451660, -1088640], [-29918990, 45262, -1658603, -331252], [-21565500, 4575932, -1532678, -451920], [89062932, -1934496, 1088472, -26064], [42021598, 1351458, 3148467, -1160232], [-88247646, 3980856, -258824, 1137740], [-93415002, -718616, -1061428, -967776], [60545986, 11281636, -549218, 599240], [-11537878, -5549656, -2029828, -1733756], [-201638194, -3467092, 420730, 1772568], [144339288, -11676864, 495648, -428280], [28473130, -4920020, 2099802, 3393048], [-33038700, 6280992, -2238000, -900504], [131773722, -9486240, 2026140, 884184], [-16311966, -7328006, -4188649, -466944], [8848294, 13608144, 948816, -1797696], [-241406430, 17295534, -2473991, 3123092], [-399817872, 8269668, 1746366, 692160], [-248959518, -1556526, 2947267, -455020], [-203687046, 17937910, 6809489, -1015320], [65900892, 24482232, -5575904, -706840], [-13797162, 21061920, 265392, -6899088], [297700602, -13185762, 721245, 2939292], [258683494, -17923310, -7580677, -1374120], [842919686, -5632664, -6080116, 2286384], [607695188, 29467208, -9839580, 2377824], [-432997146, -11421500, 6648134, -14181768], [-376809662, -7468130, -3531791, -815884], [45739878, 44299476, -16696578, 1804884], [-334346976, -12388872, -9091404, 4854216], [-89641406, -17500320, 14487960, 6025392], [-54931474, 34583310, -858867, -2455536], [155331794, 48338564, 4963982, -5669540], [-684135278, 52287676, -3654434, -4625488], [-111609602, -10489668, -15124974, 9791496], [-374647614, -12121254, 11179387, -114148], [-879577554, 45537348, 2657430, 1138296], [-627759064, 40192664, 16830496, -17164888], [489312438, 127700360, -11790692, -1326816], [-23375710, 77101172, 20373502, 10576508], [844932670, 55157048, -12985688, 14265936], [404651964, 58547100, 36074442, 9271560], [-749350736, -136247360, 16170748, 16332632], [1010518194, -21179358, -5144969, -22888084], [348274198, 136005740, 10417690, -7086360], [422397674, 41262854, 3286689, 27419676], [636121714, 67530498, 37405491, -17078160], [355653248, -1416016, 11738768, -27076472], [-2139041122, -57602896, -138008, -270244], [-2026653194, 69047098, 11723783, 4759800], [-948297488, 2955280, -32668344, -4486056], [-1182637754, -133826510, 52191995, -14920008], [-278675692, 56839832, 17817988, -13084504], [1405489018, -49070378, -7899087, 15080604], [-1264681370, -62663504, 32561648, 19886008], [-2280377516, 128664512, -3761192, -23344488], [974740574, -223510704, -43616592, 26851488], [-772240220, -330957440, 9672152, 29862936], [3616027746, -129597318, 1281079, 18818852], [-1201549444, -192224344, -3796864, 78686608], [904066874, -65805220, 57497666, -20156600], [3150818608, 173425308, 33666978, -24349584], [-1181422970, 20464056, -5360388, 35673456], [-5024164518, 138508980, -12199374, -18118812], [1312541370, 114504090, 119591187, 35498700], [-1286534892, -99746952, -145303732, 3292504], [1906695734, -179332400, 49891304, -8960112], [-1014053464, 13773168, 7387584, 90514056], [-2812125178, 54093932, 34675738, 20920920], [2140604746, 419171566, -64486327, -9592940], [510158914, 116103542, -107061503, -17859672], [3267108922, -19702514, -11644075, 41264952], [63308230, 286806148, 114947390, -10102928], [1329426630, 193934138, -83460233, 49133688], [3467407272, 115896408, -39116996, -73714624], [-1277851438, -339558472, 138374656, -20871160], [5296809252, -132468024, -11212324, -39319952], [-698033658, -62498076, -22556898, 35584248], [-6873855430, 227834384, 9811924, -38524800], [-8908752794, -227692736, 105174396, -58016736], [4997425430, -111050488, 27485120, 42929860], [588300102, -12407966, 37142771, -26769240], [3535862402, 36220796, 68530958, 133949248], [1583646614, 258247280, -25120712, -20403504], [5778820124, -271383520, 218994068, 115181368], [2222146660, -288947620, 65180194, -142231872], [2102327830, 476381408, 52033936, -183818352], [-5540540094, 340361390, 51789685, 146330664], [-2645112790, -800395096, -222356140, 113960020], [-1966232780, 361816212, -79612698, 144865800], [-1241628798, -443700216, 133265592, 71112864], [6172603530, -451677882, -44327643, -97505580], [-12285655194, -404932992, -66773088, 5329680], [6457135586, 245707682, -21632709, -35395116], [-2007143758, -422609042, 73591637, 179918040], [-4898123022, 1025856132, -284307614, -28053712], [9736279110, 715421136, 36236672, -207231896], [-1871673690, 144247646, -153203003, -45391872], [15490959410, 233262362, -41618481, -110934348], [345719444, -668283852, -164399226, -59881224], [-7213997498, -145287584, -74036876, -153811468], [-7547157958, 160053128, 39167248, -90526752], [-4779605690, 1004053384, -110516076, -74670612], [-3359976762, -221118764, 116630702, -274650984], [5569620058, -767821412, 328616258, -103992776], [-45555236, -515640728, 151703276, -83165568], [855846986, 1346154284, -116007870, -25705284], [3269019654, 776456468, 338158942, -28375944], [-1004978846, 241388956, 275422154, -173937368], [5534066360, 1284978500, 40197646, -22461552], [9089168096, 92859704, -220648600, -129515552], [-4869893072, 444498060, -153905214, 115338096], [3188885008, -539283656, 160242808, 144467696], [-1942330072, -203253704, 390986900, 75562704], [-6489096782, -1104233906, -265022895, -3976860], [-2908859954, 804301688, -129009632, -80961744], [7314939074, -1475776174, -24483573, 55678404], [-20126510666, 1028208364, 168324718, -117774820], [3317292650, -709211836, -315188610, 35531880], [12341968614, 808074658, -203062717, 142868088], [10472756932, -1005618824, -281594124, -90704592], [-11390500670, -1766106182, -243313765, 225760348], [-14873601922, -175996240, 141611272, 292120172], [-20307513792, -1389001312, -213012128, 55799352], [-2940970066, -1672254016, 491343856, -192053760], [-1274613418, -817449132, 467583198, -143075160], [22024696790, -1801174156, -541535022, 7162776], [10656297058, -18665240, -336492584, 125727644], [3070536046, 560200540, 381130490, -119704200], [-13439765868, 2335911792, -55213052, 343343576], [-42702311858, -579668396, 195481430, 128503944], [-13459043076, 872941060, 63443918, 75177384], [11336771714, 610572416, -117992, -85272208], [17384186642, -2196114522, 198866793, 81046392], [20902628354, -173702542, -335794245, 194609748], [-7207611772, -1019830692, 187924386, 357596712], [23328523994, -119366896, 391496464, -144588432], [26685160970, -1789653086, 352351955, -231455712], [-1845622396, 1056461504, -597938460, -42377712], [695143234, 2525723992, 613736720, -47069856], [33957376450, -328228574, 171341647, -309505684], [-2733275690, -321306044, 191514942, 354922308], [4954082450, -2824374532, 361848094, 1750976], [4077080974, 1095333808, 24045116, 814351296], [16545917518, -486086370, 842952357, 716957760], [-19575132714, -1531243340, 612699854, -261289896], [15012090934, 2112508228, -344620066, -86813660], [41484972530, -1555763456, -52564612, -298027728], [-6667202766, 1691350572, 241691358, 110203620], [-37948996564, 2293184392, 200499932, 399474024], [11721421418, 2261542922, 49826415, 180038580], [-42742254340, -823887856, -222547684, 180519712], [23213344474, -1322111372, -151213314, -728127528], [-17847598810, -1037537096, -585488332, -124817808], [-31882601558, 1010365744, -1298689720, -911089824], [-33098257686, 2088179538, 545452967, -567639188], [-48242875216, 684865664, -708010532, -671189344], [27031732906, -572287946, 747563513, -600447044], [32751923728, 4745880768, -483617040, -31238280], [-5386576762, 815765664, 594706488, 1035557664], [28232461122, 1861431600, -427009692, 508524144], [-26005784002, 455240108, 15728590, -583997956], [-13447310730, 554372112, -459787340, 956935184], [1902151830, 5179651122, 67775211, -125695368], [44140173984, -1272333672, -256856880, 129850968], [46762623570, -3881966334, 471809423, -488193764], [9161285064, 240431812, -680155378, 1058462592], [480764990, 2623795544, 989377624, 131126928], [-34935745410, 898442688, 1613161732, -770573776], [-9654949496, -5025877536, 437459712, 995013408], [50188411286, 2541275288, -671867368, 437212804], [-60153588590, -3101481764, 626534658, -636264516], [-28972890370, 423861744, -153608952, 1305021984], [-70064421176, 2822911024, 487938992, -346566624], [-8249217566, -268346840, -985023644, -794353408], [-111357751502, 538921528, 518585388, -513493884], [-5016336542, 3930562114, -1986148397, 504684116], [-43650962658, 3965124320, -904865720, 507132192], [-52405104542, -7466597670, 683501559, 123858288], [53818068346, -5172816566, 125864243, 315197452], [68015251814, -63217286, 1743277607, 467460984], [2698593224, 5571860312, 2542750652, -622715048], [-17734864234, 3212577192, 620246316, -1030467312], [16837880306, 2818721744, 2341856816, 879272560], [17790218476, -4578060464, 1924266784, 296688968], [-42248874740, 4505740468, 973189934, -895330848], [-406816042, 3288987092, 1851456834, 1376117436], [-134795386034, 231357424, 1132205180, -705494400], [3436722292, -7616313384, 1216862508, 548011896], [-116809749754, 1355877118, -993830515, -885372768], [8094698718, 2876040228, -624561018, -838434864], [-55829540444, 3435941512, 67695356, -833726856], [-41113294534, 8193139736, -2843219180, -555086908], [-64053006282, 8420176772, 39840598, 692523048], [168786165482, -2522926966, -257429073, 206964132], [-21156626956, -9525467680, 230683652, -276334160], [-53137426136, 882158296, 1526616224, -560552768], [-83789438662, 7498949348, 407851562, 973879444], [-16614096104, -3298052788, 558038842, 927877152], [-9429887096, 2250121880, -1794655676, -1817040864], [-1023631322, 667665532, -1884982990, 2163188328], [-71738866446, 5617372026, 750778003, -886012372], [-18712878628, -6965317576, 603231600, 1608977928], [53788029594, 3306876018, 2480780907, -28082640], [46728459886, -11826564284, 244696434, -310571844], [26204435190, -1126898250, -432212727, 2037306528], [84747105484, 1099207216, -1464389876, 234808328], [163187845870, -1645200032, -301579864, 518683152], [-104879239630, 133258190, -1110512551, 356082052], [669837294, 1306568208, -320656808, -2814393172], [-63688714130, 1275283000, 2459493044, -1910709168], [-83452741926, -7037521704, -365112512, -772354648], [-42648421162, -7823426584, 7519176, 1715949588], [-113195113614, -754544, -3326316040, -2212341984], [77365825910, -4037067754, 887818249, -235002768], [30873652402, -5751024356, -1063736362, 1149642688], [126473132878, -2528473376, -1519044256, 1755069984], [-48448179124, 3169219460, 1431890374, 1345890768], [-157940399388, 3463742088, 191247868, -129724192], [-31091553506, 10151974808, 1614877204, -370398672], [74262544902, -6525463952, 459169736, 422158752], [-191930244318, -2582113470, 1052191143, 1794680556], [138426280028, 4720920464, -1735903448, 2414131056], [61194206250, 7513311774, 977256741, -481962564], [-95798948622, -1461367746, 1461353297, -342022556], [21146203578, -7921221458, -4435376059, -253540872], [50584863390, 11170848276, -14670246, -2976143592], [-148670132126, 1949190880, 1784508068, 1980392592], [-6050403778, -4196494046, -557029597, -1478952168], [70280758262, -13525534580, -3398117038, -652302888], [158059883516, 17367213900, -849798462, -2724090360], [60123561086, 5699289424, 3588169400, 2553861888], [10944074686, 6076393766, -1911627095, -1330320864], [-156963233558, -1357260128, -453740724, 3325559964], [-56982016378, 7601777564, 3174285802, 81221400], [-66533180106, -8598973144, 768665428, 2155756896], [321371331856, -6938233712, -502215384, -1881490632], [-131261914520, 16637755312, -4012527324, 362746224], [-41865986910, 18504936786, 536235531, 54373536], [-4664876384, -2660720528, 2248621156, 475936736], [199943581662, 1981738868, -1839189194, -946339896], [-41186980390, 5586475142, -4495402055, 108439176], [44788318360, -17855520776, -1180679660, 1707931760], [-202260435826, -3150156920, 1205141072, 234687696], [-197403137430, -13623332070, 400399799, -559994588], [-71538811910, 1858609838, -1579614683, 1460419512], [21801316082, 365455220, 1744847358, 4043184840], [64453271230, -5901638528, -2805393796, -209427056], [-341388372, 5056407816, 5191135236, -666300864], [84762478386, 9342389082, 4091847235, 956688188], [-82013807122, 10577557460, 699464714, -1296032948], [-99202542050, 1117935264, -1977638484, 4510088016], [-8543454902, 13050612676, 2365159002, -145658160], [73803366360, -11040394488, 4515514980, -2867345832], [62247988770, 8445734412, -3087892146, 5410050480], [-56571920164, 13326960824, -2279266996, 2385467104], [188706216154, 10608614390, -1310877263, -90260808], [-103677461222, -11890527376, -3798977288, 3197235552], [275337774818, -12274542298, 3612454673, -195801380], [42997056580, 11257666964, 4442512822, 3872020632], [29196219316, -14488672400, -5044264120, 762849904], [15238227092, -3419391272, 2622566780, -3130872072], [225042912150, 2010328668, 10038094506, 556613976], [-267984172220, 4881987640, 1654991408, 3440698960], [347629677782, 4450068688, -897288448, 3071966400], [-85497549586, -1066145152, -6208243584, -6499805748], [18984311426, 10528660120, 3240489692, -6486281472], [-356139558452, -4164953120, 2751143992, -4352062024], [-189077594110, -16485705106, -2104974571, -1597320404], [89198289478, 4625052304, -1152222296, 2812820984], [-200828823860, 1962567208, 5791966916, -1752115104], [246645082326, -11145682212, 4566574098, -366805116], [196173542950, -3312637984, -3739056032, 4813827456], [16891852586, -724508968, 4435796072, -374459204], [75058655754, 11921619540, -2973875266, 1977878476], [-95574944434, -2545709540, 8350074290, -4533619704], [45998346366, 3466036980, 5124388662, -300309168], [81845365880, 9511318716, 6523097754, -11834856], [-35501001922, 18039212056, 1810410716, -1204871472], [31868786566, 27825923272, -2214840712, -3450663488], [-264881443606, -18661770354, -1495374315, 7335102312], [-109478168366, -26274123326, -498183609, 1023270876], [-76164706370, -21492467688, -3152512728, 684639024], [94712070322, -11560948630, -6345621209, 3074375808], [-267191280194, -925757926, -1949601161, -8543795304], [-95663967544, 24815964344, -9577588692, -2870739936], [-31750318686, -19248359880, -5586925128, 5981757768], [-367081825274, 13354573872, -7108889208, -76544112], [440416693962, 3971796264, -5156714640, 2183580312], [-199548004560, 3484057520, -2922588752, 2623297392], [-280828847786, 4161844216, -2350897384, -4383778316], [347495100254, -17420528834, 966026261, -1526586576], [281751194418, 355155180, -1423894234, 8235637636], [263040760614, -7110165828, -9328337526, -1951670328], [47459301338, 7201450574, 2113845017, 10144593268], [57574421398, 25586975964, -421550454, 29696760], [-604278324228, -6829932564, -1037474022, 964905720], [-347610355834, 2149759908, -1305033042, -2584227720], [429304013646, 6234722520, 4359021748, 1808366360], [-573629912574, 12795870594, 4223802507, 2505537012], [-157423366060, -17087663500, -6012144026, -405533112], [-342201551054, -37017343658, 4038501601, 1308094892], [10386303516, 18737319672, 1801361792, -671331584], [-325995951374, 2041624032, 11841806064, -2485123296], [-580720254, -20935932302, -10017239677, 204135024], [338786106910, 17929423012, -6053804898, -968718924], [-153735664582, 22987841540, 3696173946, 1620355104], [121039758694, -17899568646, -2505899001, -1029497064], [89017240830, -32134207060, 3561306418, 5095160136], [586914905802, 4313957586, -2133707453, 6424905188], [420804740780, 3909117044, -5596547690, -1861998480], [537389550778, -12692578688, 3309073220, -2412560208], [-382808383874, 36079660864, 2151570056, -734557448], [-328074524026, 47971667348, 2663386030, 3061753700], [-284759515862, -7517152928, -6949418444, -4603436260], [365450555882, 2009324708, -408869786, -7069681864], [73674636010, 30423463828, 4086555046, -7065145252], [146071215470, -7884126156, -3250405266, 8990788536], [582194193470, -24461407012, 4254032874, -4798098864], [-770337099644, 183164200, 3178423524, -7101223032], [-12396899878, 9146548256, 9394429652, 5526903292], [-236184475008, -25417610324, 13869741314, -7556334696], [348343597378, 35256145104, -7877750628, -2902885824], [428783449386, 33050397054, -7951048179, -5424335844], [-9982555078, 20621982838, -14556629455, 1688336040], [-556032388030, -15559518720, 889092636, 9807471552], [1037623536, 13174515120, -12351962012, 348426056], [26114231656, 24161134156, -7237228702, 3035043240], [286713353822, 27884059772, -15767260342, 6829889380], [702577590526, -16126779320, 5729099880, 5338029936], [406577722152, -26341234136, 3094123196, 1152087840], [-103227609082, -845840320, -8735775944, 5051208384], [-207657583118, -38237277812, -7703524570, -7206532364], [-132752913936, 11302908600, 760259980, 10954987808], [748499980918, -3194636392, 11485504420, 8604579024], [-247264761598, -45699059368, 12297604012, -8422798192], [-510373739062, -8478158024, 12659385752, -8323043040], [-180677121390, -32762547942, -12428213513, -2332741660], [346640494482, 52027780806, -1242601803, -18013401420], [231409815554, 24912535602, 14263238571, -6255317040], [377853040322, 2776570994, -20781734521, 5040569548], [-330061089278, -7234920742, 20286988303, -6864419520], [141848301846, 14494556496, 1769928744, 10117385532], [-884198492866, 9037815486, 336868077, 2664317808], [-245414960062, -37234977480, -5423255160, 13122999168], [252375822470, -34496408562, -4484529411, 13067918064], [-583823618188, 36225512072, -5494686972, 6756890472], [-404361949018, 35857038516, 488830302, -8229530088], [387877220506, -40958581046, -5100124001, 7284154244], [-447189140442, -14627320944, 866999956, 16881759668], [525863477844, -87882726216, 5601864156, -2614142880], [-1158290028290, 7365654580, -7740642442, 1214534020], [-436235481594, -10600685848, -11484835424, 9216918192], [308351455550, 23680649406, 7870167789, -8513948976], [-106857734210, 9098804332, 10653808714, -20143369888], [283398509116, -43413103608, 776971596, -11181206448], [206637507994, 43468443166, 8577678069, -5122288740], [-327136097154, -36209992204, -7841865794, -7034476920], [-18054394002, 75561129780, -5545237042, -2826266960], [-221953531542, 4425087098, -23481832505, -12545545296], [-499730035118, -12878094902, 18950663139, 2356468764], [2205818106, 10322752254, 16589457805, -14493085444], [-245075393760, -11270516344, -3349552220, 18208643856], [547813149942, -17158374464, -7012019992, 6617779920], [469953085106, -17465328022, -11555652797, 4740614492], [637264340418, -29613571610, -8038958791, -13017393816], [39876139134, -36068824632, -7378653848, 13953564836], [-111255807838, 38244264688, 5754925112, -5018049696], [499907571014, -15546070912, -1768876868, -22317615904], [379747622020, -97082474120, 6804329548, 729703040], [280227970808, -71026051180, -1055361074, -7473382968], [-744016970726, -17975613352, -9069381980, 1874526576], [10968998526, 16318420944, -9085820548, 2394828832], [-257229808142, 16928404648, -9490026068, 4595885012], [1253609560784, 31967781992, -1813845068, -2272007664], [425463286474, -39327531350, -25172969741, 6894775100], [474521148508, -19608804896, 14007243612, -2394112392], [708556109662, 52773475252, -8094211518, -9585637272], [454528797326, -45568846748, -17708632786, 7072707912], [619543683306, -66198326208, 9851147976, -9760547436], [1196180372472, -6789397656, 20732485560, 1531627848], [-116872865786, -57243689464, -10981125044, 16413756912], [-277256313766, 6016422386, 17516925731, -15667475132], [659905953624, -1611300576, -13119563840, -9518728456], [170593880754, 35009231754, 7564268363, -6155981972], [-1201996229886, -49584674222, 309446291, 18829937232], [281027284672, 4306452472, -8248909184, -17111650048]]
